Branch: refs/heads/main
  Home:   https://github.com/WebKit/WebKit
  Commit: e3ff851cf042ad6f503a2724952b6d4217f359f8
      
https://github.com/WebKit/WebKit/commit/e3ff851cf042ad6f503a2724952b6d4217f359f8
  Author: Justin Michaud <[email protected]>
  Date:   2026-10-05 (Mon, 05 Oct 2026)

  Changed paths:
    A JSTests/microbenchmarks/value-sub-double-result.js
    A JSTests/stress/value-sub-arith-profile-double-result.js
    M Source/JavaScriptCore/dfg/DFGByteCodeParser.cpp

  Log Message:
  -----------
  DFG makeSafe should read arith profile for ValueSub too
https://bugs.webkit.org/show_bug.cgi?id=326000

Reviewed by Yusuke Suzuki.

@nikolaszimmermann noticed this in one of our testing applications.
We get repeated OSR exits because we always profile ValueSub's operands
as ints even when the site sees doubles.

ValueSub already has an ArithProfile, it seems that it just got missed by
prevous optimizations touching this code.

value-sub-double-result ^ definitely 1.1457x faster

Canonical link: https://commits.webkit.org/322704@main



To unsubscribe from these emails, change your notification settings at 
https://github.com/WebKit/WebKit/settings/notifications

Reply via email to